@@ -1,8 +1,17 @@
-/*
- * module.c
+#ident "$Id: module.c,v 1.2 1997/10/06 21:44:07 hpa Exp $"
+/* ----------------------------------------------------------------------- *
  *
- * Common module-management functions
- */
+ *  module.c - common module-management functions
+ *
+ *   Copyright 1997 Transmeta Corporation - All Rights Reserved
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA 02139,
+ *   USA; either version 2 of the License, or (at your option) any later
+ *   version; incorporated herein by reference.
+ *
+ * ----------------------------------------------------------------------- */
 
 #include <stdio.h>
 #include <syslog.h>
@@ -11,8 +20,9 @@
 #include <stdlib.h>
 #include "automount.h"
 
-struct lookup_mod *open_lookup(char *name, char *err_prefix,
-			       char *mapfmt, int argc, char **argv)
+struct lookup_mod *open_lookup(const char *name, const char *err_prefix,
+			       const char *mapfmt,
+			       int argc, const char * const *argv)
 {
   struct lookup_mod *mod;
   char *fnbuf;
@@ -76,8 +86,8 @@ int close_lookup(struct lookup_mod *mod)
   return rv;
 }
 
-struct parse_mod *open_parse(char *name, char *err_prefix,
-			      int argc, char **argv)
+struct parse_mod *open_parse(const char *name, const char *err_prefix,
+			      int argc, const char * const *argv)
 {
   struct parse_mod *mod;
   char *fnbuf;
@@ -141,7 +151,7 @@ int close_parse(struct parse_mod *mod)
   return rv;
 }
 
-struct mount_mod *open_mount(char *name, char *err_prefix)
+struct mount_mod *open_mount(const char *name, const char *err_prefix)
 {
   struct mount_mod *mod;
   char *fnbuf;
