@@ -1,6 +1,7 @@
+#ident "$Id: spawn.c,v 1.2 1997/10/06 21:44:07 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  * 
- * spawn.c - run programs synchronously with output redirected to syslog
+ *  spawn.c - run programs synchronously with output redirected to syslog
  *   
  *   Copyright 1997 Transmeta Corporation - All Rights Reserved
  *
@@ -47,7 +48,7 @@ void reset_signals(void)
 
 #define ERRBUFSIZ 2047		/* Max length of error string excl \0 */
 
-int spawnv(int logpri, char *prog, char **argv) {
+int spawnv(int logpri, const char *prog, const char * const *argv) {
   pid_t f;
   int status, pipefd[2];
   char errbuf[ERRBUFSIZ+1], *p, *sp;
@@ -70,7 +71,7 @@ int spawnv(int logpri, char *prog, char **argv) {
     dup2(pipefd[1], STDOUT_FILENO);
     dup2(pipefd[1], STDERR_FILENO);
     close(pipefd[1]);
-    execv(prog, argv);
+    execv(prog, (char * const *)argv);
     _exit(255);	/* execv() failed */
   } else {
     /* Careful here -- if we enable SIGCHLD yet we may not receive the
@@ -133,7 +134,7 @@ int spawnv(int logpri, char *prog, char **argv) {
   }
 }
 
-int spawnl(int logpri, char *prog, ...)
+int spawnl(int logpri, const char *prog, ...)
 {
   va_list arg;
   int argc;
@@ -151,6 +152,6 @@ int spawnl(int logpri, char *prog, ...)
   while ((*p++ = va_arg(arg,char *)));
   va_end(arg);
   
-  return spawnv(logpri, prog, argv);
+  return spawnv(logpri, prog, (const char **)argv);
 }
 
