@@ -1,10 +1,18 @@
-/*
- * mount_generic.c
+#ident "$Id: mount_generic.c,v 1.4 1998/04/01 11:15:47 hpa Exp $"
+/* ----------------------------------------------------------------------- *
+ *   
+ *  mount_generic.c - module for Linux automountd to mount filesystems
+ *                    for which no special magic is required
  *
- * Module for Linux automountd to mount filesystems for which no special
- * magic is required
+ *   Copyright 1997 Transmeta Corporation - All Rights Reserved
  *
- */
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA 02139,
+ *   USA; either version 2 of the License, or (at your option) any later
+ *   version; incorporated herein by reference.
+ *
+ * ----------------------------------------------------------------------- */
 
 #include <stdio.h>
 #include <malloc.h>
@@ -23,14 +31,14 @@
 #define MODPREFIX "mount(generic): "
 int mount_version = AUTOFS_MOUNT_VERSION; /* Required by protocol */
 
-
 int mount_init(void **context)
 {
   return 0;
 }
 
-int mount_mount(char *root, char *name, int name_len, char *what,
-		char *fstype, char *options, void *context)
+int mount_mount(const char *root, const char *name, int name_len,
+		const char *what, const char *fstype, const char *options,
+		void *context)
 {
   char *fullpath;
   int err;
@@ -49,14 +57,14 @@ int mount_mount(char *root, char *name, int name_len, char *what,
   }
     
   if ( options ) {
-    syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s -o %s %s %s",
+    syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s " SLOPPY "-o %s %s %s",
 	   fstype, options, what, fullpath);
-    err = spawnl(LOG_NOTICE, _PATH_MOUNT, _PATH_MOUNT, "-t", fstype,
-		 "-o", options, what, fullpath, NULL);
+    err = spawnl(LOG_NOTICE, PATH_MOUNT, PATH_MOUNT, "-t", fstype,
+		 SLOPPYOPT "-o", options, what, fullpath, NULL);
   } else {
     syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s %s %s",
 	   fstype, what, fullpath);
-      err = spawnl(LOG_NOTICE, _PATH_MOUNT, _PATH_MOUNT, "-t", fstype,
+      err = spawnl(LOG_NOTICE, PATH_MOUNT, PATH_MOUNT, "-t", fstype,
 		   what, fullpath, NULL);
   }
   if ( err ) {
