@@ -1,4 +1,4 @@
-#ident "$Id: mount_nfs.c,v 1.6 1998/04/06 10:58:15 hpa Exp $"
+#ident "$Id: mount_nfs.c,v 1.7 1998/04/09 23:31:58 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  * mount_nfs.c - Module for Linux automountd to mount an NFS filesystem,
@@ -184,8 +184,8 @@ int mount_mount(const char *root, const char *name, int name_len,
     if ( options ) {
       syslog(LOG_DEBUG, MODPREFIX "calling mount -t nfs " SLOPPY "-o %s %s %s",
 	     options, whatstr, fullpath);
-      err = spawnl(LOG_NOTICE, PATH_MOUNT, PATH_MOUNT, "-t", "nfs", "-o",
-		   SLOPPYOPT options, whatstr, fullpath, NULL);
+      err = spawnl(LOG_NOTICE, PATH_MOUNT, PATH_MOUNT, "-t", "nfs",
+		   SLOPPYOPT "-o", options, whatstr, fullpath, NULL);
     } else {
       syslog(LOG_DEBUG, MODPREFIX "calling mount -t nfs %s %s", whatstr, fullpath);
       err = spawnl(LOG_NOTICE, PATH_MOUNT, PATH_MOUNT, "-t", "nfs",
